==> cms-db_v0.9.tar.gz: admin/blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('blog');
include('locale.inc.php');
$locale = new LocalizingClass('blog');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_blog') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('desc_blog') ?></h1>

<?php
if (isset($_GET['deleted'])) {
	echo '<p class="success">'.locale('desc_blogentry-deleted',true).'</p>';
}
?>
<p class="linklist_action">
	<a href="newblogentry.php?<?php echo SID; csrf_protection_get_html() ?>" class="nonewtab"><img src="icons-action/create-blogentry.png" style="vertical-align:middle" alt="" height="16" width="16" /> <?php locale('link_new-blogentry') ?></a>
</p>
<ul class="linklist">
<?php
$entries = false;

$drafts = array();
if ($handle = opendir('../data/blog/.autosave')) {
	while (false !== ($file = readdir($handle))) {
		if (substr($file, 0, 3) === 'new') {
			$drafts[filemtime('../data/blog/.autosave/'.$file)] = $file;
		}
	}
	closedir($handle);
}
if (count($drafts) != 0) {
	$entries = true;
	ksort($drafts);
	$drafts = array_reverse($drafts);
	foreach ($drafts as $draft) {
		$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
		$data = file_get_contents('../data/blog/.autosave/'.$draft);
		$data = explode("\n", $data, 3);
		$title = $data[0];
		//$tags = $data[1];
		//$text = $data[2];
		echo '<li class="'.$class.'">';
		echo '<span class="list_name">'.$title.'</span> ';
		echo '<span class="list_info">';
		echo '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align:middle" /> '.locale('desc_draft',true).' &bull; ';
		echo '<a href="blogentry.php?id='.$draft.'&amp;action_edit&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('button_edit-blogentry',true).'</a> &bull; ';
		echo '<a href="blogentry.php?id='.$draft.'&amp;action_delete&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_delete',true).'</a>';
		echo '</span>';
		echo '</li>';
	}
}

$articles = array();
if ($handle = opendir('../data/blog/articles')) {
	while (false !== ($file = readdir($handle))) {
		if ($file != '.' && $file != '..') {
			$articles[] = $file;
		}
	}
	closedir($handle);
}
if (count($articles) != 0) {
	$entries = true;
	natsort($articles);
	$articles = array_reverse($articles);
	foreach ($articles as $article) {
		$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
		$data = file_get_contents('../data/blog/articles/'.$article.'/content');
		$data = explode("\n", $data, 5);
		$title = $data[0];
		//$author = $data[1];
		$time = $data[2];
		//$tags = $data[3];
		//$text = $data[4];
		$desc = locale('desc_published',true).' '.date('d.m.Y', $time);
		if (file_exists('../data/blog/.autosave/'.$article))
			$desc = '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align:middle" /> '.locale('desc_draft',true).' &bull; '.$desc;
		echo '<li class="'.$class.'">';
		echo '<span class="list_name">'.$title.'</span> ';
		echo '<span class="list_info">';
		echo $desc.' &bull; ';
		echo '<a href="blogentry.php?id='.$article.'&amp;action_edit&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('button_edit-blogentry',true).'</a> &bull; ';
		echo '<a href="blogentry.php?id='.$article.'&amp;action_delete&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_delete',true).'</a>';
		echo '</span>';
		echo '</li>';
	}
}
?>
</ul>
<?php
if (!$entries) {
	echo '<p class="box">'.locale('desc_noblogentries',true).'</p>';
}
?>

</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('blog');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('blog');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_blog') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('desc_blog') ?></h1>

<?php
if (isset($_GET['deleted'])) {
	echo '<p class="success">'.locale('desc_blogentry-deleted',true).'</p>';
}
?>
<p class="linklist_action">
	<a href="newblogentry.php?<?php echo SID; csrf_protection_get_html() ?>" class="nonewtab"><img src="icons-action/create-blogentry.png" style="vertical-align:middle" alt="" height="16" width="16" /> <?php locale('link_new-blogentry') ?></a>
</p>
<ul class="linklist">
<?php
$entries = false;

$drafts = array();
if ($handle = opendir('../data/blog/.autosave')) {
	while (false !== ($file = readdir($handle))) {
		if (substr($file, 0, 3) === 'new') {
			$drafts[filemtime('../data/blog/.autosave/'.$file)] = $file;
		}
	}
	closedir($handle);
}
if (count($drafts) != 0) {
	$entries = true;
	ksort($drafts);
	$drafts = array_reverse($drafts);
	foreach ($drafts as $draft) {
		$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
		$data = file_get_contents('../data/blog/.autosave/'.$draft);
		$data = explode("\n", $data, 3);
		$title = $data[0];
		//$tags = $data[1];
		//$text = $data[2];
		echo '<li class="'.$class.'">';
		echo '<span class="list_name">'.$title.'</span> ';
		echo '<span class="list_info">';
		echo '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align:middle" /> '.locale('desc_draft',true).' &bull; ';
		echo '<a href="blogentry.php?id='.$draft.'&amp;action_edit&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('button_edit-blogentry',true).'</a> &bull; ';
		echo '<a href="blogentry.php?id='.$draft.'&amp;action_delete&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_delete',true).'</a>';
		echo '</span>';
		echo '</li>';
	}
}

$articles = array();
if ($handle = opendir('../data/blog/articles')) {
	while (false !== ($file = readdir($handle))) {
		if ($file != '.' && $file != '..') {
			$articles[] = $file;
		}
	}
	closedir($handle);
}
if (count($articles) != 0) {
	$entries = true;
	natsort($articles);
	$articles = array_reverse($articles);
	foreach ($articles as $article) {
		$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
		$data = file_get_contents('../data/blog/articles/'.$article.'/content');
		$data = explode("\n", $data, 5);
		$title = $data[0];
		//$author = $data[1];
		$time = $data[2];
		//$tags = $data[3];
		//$text = $data[4];
		$desc = locale('desc_published',true).' '.date('d.m.Y', $time);
		if (file_exists('../data/blog/.autosave/'.$article))
			$desc = '<img src="unpublished.png" width="16" height="16" alt="" style="vertical-align:middle" /> '.locale('desc_draft',true).' &bull; '.$desc;
		echo '<li class="'.$class.'">';
		echo '<span class="list_name">'.$title.'</span> ';
		echo '<span class="list_info">';
		echo $desc.' &bull; ';
		echo '<a href="blogentry.php?id='.$article.'&amp;action_edit&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('button_edit-blogentry',true).'</a> &bull; ';
		echo '<a href="blogentry.php?id='.$article.'&amp;action_delete&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_delete',true).'</a>';
		echo '</span>';
		echo '</li>';
	}
}
?>
</ul>
<?php
if (!$entries) {
	echo '<p class="box">'.locale('desc_noblogentries',true).'</p>';
}
?>

</body>
</html>
